==> web-fw2_2_2.zip: web-fw2_2_2/j2src/sample/org/itscool/webersample/action/user/RegistUserAction.java <==
/*
 * 쐬: 2005/07/18
 * 쐬: KANO
 */
package org.itscool.webersample.action.user;

import org.itscool.weber.action.Action;
import org.itscool.weber.action.ActionBucket;
import org.itscool.weber.user.User;
import org.itscool.weber.user.UserDao;
import org.itscool.weber.user.UserRole;
import org.itscool.weber.user.UserRoleDao;
import org.itscool.weber.user.UserUtil;

/**
 * [Uo^ANV
 * 
 * @author KANO
 * @version 1.00
 */
public class RegistUserAction extends Action{
public static final String DEVELOP_USER="develop";
	
    /**
     * ͂ꂽ[Ǔ؏
     */
	protected void doValidate() {
		UserDao dao = new UserDao();
		User user = dao.getUser(DEVELOP_USER, (String)getParameter("name"));
		if( getParameter("submit_add") != null ){
			if(user != null && user.getName() != null && user.getName().length() > 0 ){
				putMessage("duplicate", "[UdĂ܂");
			}
			else if (!isNotNull("name")) {
				putMessage("name", "[U͂Ă");
			}
		}else if( getParameter("submit_update") != null){
		    if (!isNotNull("name")) {
				putMessage("name", "[U͂Ă");
			}
		}
		if (!isNotNull("pwd")) {
			putMessage("pwd", "pX[h͂Ă");
		}
    }
    
	/**
	 * [Uo^
	 * 
	 * @param bucket ActionBucket
     * @return ɏIꍇ"success"Ԃ܂
	 */
    public String doExecute(ActionBucket bucket) throws Exception{
        User user = (User)bucket.getForm();
		
        if( getParameter("submit_add") != null ){
        	UserRoleDao roleDao = new UserRoleDao();
    		UserRole role = roleDao.getRole(DEVELOP_USER);
    		user.setRole(role);
        	user.setRoleId(role.getId());
        	
        	//[Uǉ
        	UserUtil.insertUser(user);
        	
        }else if(getParameter("submit_update") != null ){
        	UserUtil.updateUser(user);
        	
        }else if(getParameter("submit_delete") != null ){
        	UserUtil.deleteUser(user);
        	
        }
        return "success";
    }
}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/sample/org/itscool/webersample/action/user/RegistUserAction.java <==
/*
 * 쐬: 2005/07/18
 * 쐬: KANO
 */
package org.itscool.webersample.action.user;

import org.itscool.weber.action.Action;
import org.itscool.weber.action.ActionBucket;
import org.itscool.weber.user.User;
import org.itscool.weber.user.UserDao;
import org.itscool.weber.user.UserRole;
import org.itscool.weber.user.UserRoleDao;
import org.itscool.weber.user.UserUtil;

/**
 * [Uo^ANV
 * 
 * @author KANO
 * @version 1.00
 */
public class RegistUserAction extends Action{
public static final String DEVELOP_USER="develop";
	
    /**
     * ͂ꂽ[Ǔ؏
     */
	protected void doValidate() {
		UserDao dao = new UserDao();
		User user = dao.getUser(DEVELOP_USER, (String)getParameter("name"));
		if( getParameter("submit_add") != null ){
			if(user != null && user.getName() != null && user.getName().length() > 0 ){
				putMessage("duplicate", "[UdĂ܂");
			}
			else if (!isNotNull("name")) {
				putMessage("name", "[U͂Ă");
			}
		}else if( getParameter("submit_update") != null){
		    if (!isNotNull("name")) {
				putMessage("name", "[U͂Ă");
			}
		}
		if (!isNotNull("pwd")) {
			putMessage("pwd", "pX[h͂Ă");
		}
    }
    
	/**
	 * [Uo^
	 * 
	 * @param bucket ActionBucket
     * @return ɏIꍇ"success"Ԃ܂
	 */
    public String doExecute(ActionBucket bucket) throws Exception{
        User user = (User)bucket.getForm();
		
        if( getParameter("submit_add") != null ){
        	UserRoleDao roleDao = new UserRoleDao();
    		UserRole role = roleDao.getRole(DEVELOP_USER);
    		user.setRole(role);
        	user.setRoleId(role.getId());
        	
        	//[Uǉ
        	UserUtil.insertUser("guest", user);
        	
        }else if(getParameter("submit_update") != null ){
        	UserUtil.updateUser("guest", user);
        	
        }else if(getParameter("submit_delete") != null ){
        	UserUtil.deleteUser("guest", user);
        	
        }
        return "success";
    }
}
